@@ -45,6 +45,7 @@ from traitlets import (
 from traitlets.config.configurable import MultipleInstanceError
 from zmq.eventloop.zmqstream import ZMQStream
 
+import ipyparallel as ipp
 from ipyparallel import error, serialize, util
 from ipyparallel.serialize import PrePickled, Reference
 
@@ -178,7 +179,7 @@ class ExecuteReply(RichOutput):
         return ''.join(
             [
                 out,
-                'Out[%i:%i]: ' % (self.metadata['engine_id'], self.execution_count),
+                f"Out[{self.metadata['engine_id']}:{self.execution_count}]: ",
                 normal,
                 text_out,
             ]
@@ -402,7 +403,6 @@ class Client(HasTraits):
         cluster=None,
         **extra_args,
     ):
-
         super_kwargs = {'debug': debug, 'cluster': cluster}
         if profile:
             super_kwargs['profile'] = profile
@@ -507,7 +507,7 @@ class Client(HasTraits):
             'registration',
             'broadcast',
         ):
-            cfg[key] = cfg['interface'] + ':%i' % cfg[key]
+            cfg[key] = f"{cfg['interface']}:{cfg[key]}"
 
         url = cfg['registration']
 
@@ -524,7 +524,6 @@ class Client(HasTraits):
                 and not sshserver
                 and location != socket.gethostname()
             ):
-
                 # warn if no ssh specified, but SSH is probably needed
                 # This is only a warning, because the most likely cause
                 # is a local Controller on a laptop whose IP is dynamic
@@ -710,7 +709,7 @@ class Client(HasTraits):
             if targets < 0:
                 targets = self.ids[targets]
             if targets not in self._ids:
-                raise IndexError("No such engine: %i" % targets)
+                raise IndexError(f"No such engine: {targets}")
             targets = [targets]
 
         if isinstance(targets, slice):
@@ -1504,7 +1503,10 @@ class Client(HasTraits):
             seconds_remaining = 1000
 
         if interactive is None:
-            interactive = get_ipython() is not None
+            if ipp._NONINTERACTIVE:
+                interactive = False
+            else:
+                interactive = get_ipython() is not None
 
         if interactive:
             progress_bar = util.progress(
@@ -1524,10 +1526,17 @@ class Client(HasTraits):
                 if not engine_stop_future.done():
                     engine_stop_future.set_result(stop_data)
 
+            def _remove_signal_stopped(f, es):
+                try:
+                    es.stop_callbacks.remove(_signal_stopped)
+                except ValueError:
+                    # already removed
+                    pass
+
             for es in self.cluster.engines.values():
                 es.on_stop(_signal_stopped)
                 engine_stop_future.add_done_callback(
-                    lambda f: es.stop_callbacks.remove(_signal_stopped)
+                    partial(_remove_signal_stopped, es=es)
                 )
 
         future = Future()
