@@ -17,23 +17,25 @@ import zmq
 from jupyter_client.jsonutil import parse_date
 from jupyter_client.session import Session
 from tornado import ioloop
-from traitlets import Any
-from traitlets import Bytes
-from traitlets import default
-from traitlets import Dict
-from traitlets import Float
-from traitlets import HasTraits
-from traitlets import Instance
-from traitlets import Integer
-from traitlets import Set
-from traitlets import Unicode
+from traitlets import (
+    Any,
+    Bytes,
+    Dict,
+    Float,
+    HasTraits,
+    Instance,
+    Integer,
+    Set,
+    Unicode,
+    default,
+)
 from traitlets.config import LoggingConfigurable
 from zmq.eventloop.zmqstream import ZMQStream
 
+from ipyparallel import error, util
+
 from ..util import extract_dates
 from .heartmonitor import HeartMonitor
-from ipyparallel import error
-from ipyparallel import util
 
 # internal:
 
@@ -874,7 +876,7 @@ class Hub(LoggingConfigurable):
         )
 
     def register_engine(self, reg, msg):
-        """Register a new engine."""
+        """Begin registration of a new engine."""
         content = msg['content']
         try:
             uuid = content['uuid']
@@ -899,8 +901,8 @@ class Hub(LoggingConfigurable):
                 content = error.wrap_exception()
                 self.log.error("uuid %r in use", uuid, exc_info=True)
         else:
-            for h, ec in self.incoming_registrations.items():
-                if uuid == h:
+            for heart_id, ec in self.incoming_registrations.items():
+                if uuid == heart_id:
                     try:
                         raise KeyError("heart_id %r in use" % uuid)
                     except:
@@ -951,10 +953,22 @@ class Hub(LoggingConfigurable):
             )
             return
         if eid not in self.engines:
-            self.log.info(
-                f"registration::unregister_engine({eid}) already unregistered"
-            )
+            # engine not registered
+            # first, check for still-pending registration
+            remove_heart_id = None
+            for heart_id, ec in self.incoming_registrations.items():
+                if ec.id == eid:
+                    remove_heart_id = heart_id
+                    break
+            if remove_heart_id is not None:
+                self.log.info(f"registration::canceling registration {ec.id}:{ec.uuid}")
+                self.incoming_registrations.pop(remove_heart_id)
+            else:
+                self.log.info(
+                    f"registration::unregister_engine({eid}) already unregistered"
+                )
             return
+
         self.log.info(f"registration::unregister_engine({eid})")
         ec = self.engines[eid]
 
@@ -1050,7 +1064,7 @@ class Hub(LoggingConfigurable):
     def _purge_stalled_registration(self, heart):
         # flush monitor messages before purging
         # first heartbeat might be waiting to be handled
-        self.mon_stream.flush()
+        self.monitor.flush()
         if heart in self.incoming_registrations:
             ec = self.incoming_registrations.pop(heart)
             self.log.warning(
